@@ -295,6 +295,52 @@ void removeFormatFiles(const QString &path, const QVariantMap &mimeToExtension)
         QFile::remove(path + extValue.toString());
 }
 
+bool renameToUnique(
+        const QDir &dir, const QStringList &baseNames, QString *name,
+        const QList<FileFormat> &formatSettings)
+{
+    if ( name->isEmpty() ) {
+        *name = "copyq_0000";
+    } else {
+        // Replace/remove unsafe characters.
+        name->replace( QRegExp("/|\\\\|^\\."), QString("_") );
+        name->remove( QRegExp("\\n|\\r") );
+    }
+
+    const QStringList fileNames = dir.entryList();
+
+    if ( isUniqueBaseName(*name, fileNames, baseNames) )
+        return true;
+
+    QString ext;
+    QString baseName;
+    getBaseNameAndExtension(*name, &baseName, &ext, formatSettings);
+
+    int i = 0;
+    int fieldWidth = 0;
+
+    QRegExp re("\\d+$");
+    if ( baseName.indexOf(re) != -1 ) {
+        const QString num = re.cap(0);
+        i = num.toInt();
+        fieldWidth = num.size();
+        baseName = baseName.mid( 0, baseName.size() - fieldWidth );
+    } else {
+        baseName.append('-');
+    }
+
+    QString newName;
+    do {
+        if (i >= 99999)
+            return false;
+        newName = baseName + QString("%1").arg(++i, fieldWidth, 10, QChar('0')) + ext;
+    } while ( !isUniqueBaseName(newName, fileNames, baseNames) );
+
+    *name = newName;
+
+    return true;
+}
+
 } // namespace
 
 QString FileWatcher::getBaseName(const QModelIndex &index)
@@ -372,15 +418,15 @@ FileWatcher::FileWatcher(
         m_updateTimer.setInterval(100);
 #endif
 
-    connect( &m_updateTimer, SIGNAL(timeout()),
-             SLOT(updateItems()) );
+    connect( &m_updateTimer, &QTimer::timeout,
+             this, &FileWatcher::updateItems );
 
-    connect( m_model.data(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-             this, SLOT(onRowsInserted(QModelIndex,int,int)), Qt::UniqueConnection );
-    connect( m_model.data(), SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-             this, SLOT(onRowsRemoved(QModelIndex,int,int)), Qt::UniqueConnection );
-    connect( m_model.data(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-             SLOT(onDataChanged(QModelIndex,QModelIndex)), Qt::UniqueConnection );
+    connect( m_model.data(), &QAbstractItemModel::rowsInserted,
+             this, &FileWatcher::onRowsInserted );
+    connect( m_model.data(), &QAbstractItemModel::rowsAboutToBeRemoved,
+             this, &FileWatcher::onRowsRemoved );
+    connect( m_model.data(), &QAbstractItemModel::dataChanged,
+             this, &FileWatcher::onDataChanged );
 
     if (model->rowCount() > 0)
         saveItems(0, model->rowCount() - 1);
@@ -395,6 +441,7 @@ bool FileWatcher::lock()
     if ( !m_valid )
         return false;
 
+    m_updateTimer.stop();
     m_valid = false;
     return true;
 }
@@ -402,6 +449,7 @@ bool FileWatcher::lock()
 void FileWatcher::unlock()
 {
     m_valid = true;
+    m_updateTimer.start();
 }
 
 bool FileWatcher::createItemFromFiles(const QDir &dir, const BaseNameExtensions &baseNameWithExts, int targetRow)
@@ -435,12 +483,10 @@ void FileWatcher::createItemsFromFiles(const QDir &dir, const BaseNameExtensions
 
 void FileWatcher::updateItems()
 {
-    m_updateTimer.stop();
-
     if ( !lock() )
         return;
 
-    QDir dir(m_path);
+    const QDir dir(m_path);
     const QStringList files = listFiles(dir, QDir::Time | QDir::Reversed);
     BaseNameExtensionsList fileList = listFiles(files, m_formatSettings);
 
@@ -471,8 +517,6 @@ void FileWatcher::updateItems()
     createItemsFromFiles(dir, fileList);
 
     unlock();
-
-    m_updateTimer.start();
 }
 
 void FileWatcher::onRowsInserted(const QModelIndex &, int first, int last)
@@ -643,50 +687,6 @@ void FileWatcher::saveItems(int first, int last)
     unlock();
 }
 
-bool FileWatcher::renameToUnique(const QDir &dir, const QStringList &baseNames, QString *name)
-{
-    if ( name->isEmpty() ) {
-        *name = "copyq_0000";
-    } else {
-        // Replace/remove unsafe characters.
-        name->replace( QRegExp("/|\\\\|^\\."), QString("_") );
-        name->remove( QRegExp("\\n|\\r") );
-    }
-
-    const QStringList fileNames = dir.entryList();
-
-    if ( isUniqueBaseName(*name, fileNames, baseNames) )
-        return true;
-
-    QString ext;
-    QString baseName;
-    getBaseNameAndExtension(*name, &baseName, &ext, m_formatSettings);
-
-    int i = 0;
-    int fieldWidth = 0;
-
-    QRegExp re("\\d+$");
-    if ( baseName.indexOf(re) != -1 ) {
-        const QString num = re.cap(0);
-        i = num.toInt();
-        fieldWidth = num.size();
-        baseName = baseName.mid( 0, baseName.size() - fieldWidth );
-    } else {
-        baseName.append('-');
-    }
-
-    QString newName;
-    do {
-        if (i >= 99999)
-            return false;
-        newName = baseName + QString("%1").arg(++i, fieldWidth, 10, QChar('0')) + ext;
-    } while ( !isUniqueBaseName(newName, fileNames, baseNames) );
-
-    *name = newName;
-
-    return true;
-}
-
 bool FileWatcher::renameMoveCopy(const QDir &dir, const QList<QPersistentModelIndex> &indexList)
 {
     QStringList baseNames;
@@ -703,7 +703,7 @@ bool FileWatcher::renameMoveCopy(const QDir &dir, const QList<QPersistentModelIn
         bool newItem = olderBaseName.isEmpty();
         bool itemRenamed = olderBaseName != baseName;
         if ( newItem || itemRenamed ) {
-            if ( !renameToUnique(dir, baseNames, &baseName) )
+            if ( !renameToUnique(dir, baseNames, &baseName, m_formatSettings) )
                 return false;
             itemRenamed = olderBaseName != baseName;
             baseNames.append(baseName);
@@ -785,7 +785,7 @@ bool FileWatcher::copyFilesFromUriList(const QByteArray &uriData, int targetRow,
                 getBaseNameAndExtension( QFileInfo(f).fileName(), &baseName, &extName,
                                          m_formatSettings );
 
-                if ( renameToUnique(dir, baseNames, &baseName) ) {
+                if ( renameToUnique(dir, baseNames, &baseName, m_formatSettings) ) {
                     const QString targetFilePath = dir.absoluteFilePath(baseName + extName);
                     f.copy(targetFilePath);
                     Ext ext;
