@@ -84,8 +84,8 @@ class ItemTagsLoader;
 class ItemTagsScriptable : public ItemScriptable
 {
     Q_OBJECT
-    Q_PROPERTY(QStringList userTags READ getUserTags)
-    Q_PROPERTY(QString mimeTags READ getMimeTags)
+    Q_PROPERTY(QStringList userTags READ getUserTags CONSTANT)
+    Q_PROPERTY(QString mimeTags READ getMimeTags CONSTANT)
 
 public:
     explicit ItemTagsScriptable(const QStringList &userTags)
@@ -152,12 +152,11 @@ public:
 
     QVector<Command> commands() const override;
 
-private slots:
+private:
     void onColorButtonClicked();
     void onTableWidgetItemChanged(QTableWidgetItem *item);
-    void onTableWidgetItemChanged();
+    void onAllTableWidgetItemsChanged();
 
-private:
     QStringList userTags() const;
 
     using Tag = ItemTags::Tag;
