@@ -56,17 +56,19 @@ protected:
 
     void mouseDoubleClickEvent(QMouseEvent *e) override;
 
-private slots:
+    QSize sizeHint() const override;
+
+private:
     void onSelectionChanged();
     void onLinkClicked(const QUrl &url);
 
-private slots:
     void onItemChanged();
 
-private:
     bool m_copyOnMouseUp;
     int m_maximumHeight;
     QSize m_maximumSize;
+    int m_idealWidth = 100;
+    bool m_resizing = false;
     bool m_preview;
 };
 
