@@ -60,14 +60,14 @@ public:
 
     void exit(int exitCode) override;
 
-    void sendFunctionCall(const QByteArray &bytes);
-
     void startInputReader();
 
 signals:
     void functionCallResultReceived(const QByteArray &returnValue);
     void inputReceived(const QByteArray &input);
+    void inputDialogFinished(const QByteArray &data);
     void stopEventLoops();
+    void scriptableFinished();
 
 private:
     void onMessageReceived(const QByteArray &data, int messageCode);
