@@ -24,7 +24,8 @@
 #include <QProcess>
 #include <QStringList>
 #include <QVariantMap>
-#include <QVector>
+
+#include <vector>
 
 class QAction;
 
@@ -102,7 +103,6 @@ public:
     void appendOutput(const QByteArray &output);
     void appendErrorOutput(const QByteArray &errorOutput);
 
-public slots:
     /** Terminate (kill) process. */
     void terminate();
 
@@ -114,7 +114,7 @@ signals:
 
     void actionOutput(const QByteArray &output);
 
-private slots:
+private:
     void onSubProcessError(QProcess::ProcessError error);
     void onSubProcessStarted();
     void onSubProcessFinished();
@@ -123,9 +123,8 @@ private slots:
     void writeInput();
     void onBytesWritten();
 
-private:
     void closeSubCommands();
-    void actionFinished();
+    void finish();
 
     QByteArray m_input;
     QList< QList<QStringList> > m_cmds;
@@ -137,7 +136,7 @@ private:
     int m_currentLine;
     QString m_name;
     QVariantMap m_data;
-    QVector<QProcess*> m_processes;
+    std::vector<QProcess*> m_processes;
 
     int m_exitCode;
     QString m_errorString;
