@@ -19,8 +19,8 @@
 
 #include "temporarysettings.h"
 
-#include "common/common.h"
 #include "common/log.h"
+#include "common/temporaryfile.h"
 
 #include <QTemporaryFile>
 
