@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2017, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -24,6 +24,7 @@
 #include "common/textdata.h"
 #include "common/version.h"
 #include "gui/icons.h"
+#include "gui/iconfont.h"
 
 namespace {
 
@@ -91,7 +92,7 @@ QString AboutDialog::aboutPage()
         "#subtitle{font-size:16pt;color:#888;white-space:pre;margin-bottom:0.2em}"
         "#version{font-size:12pt}"
         ".copyright{font-size:9pt;color:#666}"
-        ".icon{font-family:FontAwesome}"
+        ".icon{font-family:" + iconFontFamily() + "}"
         ".help-icon{color:#999;padding-left:1em;padding-right:1em}"
         ".library{font-size:12pt}"
         ".info{color:#666}"
@@ -118,7 +119,7 @@ QString AboutDialog::aboutPage()
         "</table>"
         "</p>"
 
-        "<p class='copyright'>Copyright (c) 2009 - 2017</p>"
+        "<p class='copyright'>Copyright (c) 2009 - 2018</p>"
 
         "<p></p>"
 
@@ -147,12 +148,12 @@ QString AboutDialog::aboutPage()
             +
         "</p>"
 
-            + helpLib("Qt",
-                      "The Qt Toolkit is Copyright (C) 2016 The Qt Company Ltd. and other contributors.", "https://www.qt.io/")
+            + helpLib("Qt Toolkit",
+                      "Copyright (c) 2016 The Qt Company Ltd. and other contributors", "https://www.qt.io/")
             + helpLib("Weblate",
-                      "Copyright (c) 2012 - 2016 Michal &#268;iha&#345;", "https://weblate.org")
+                      "Copyright (c) 2012 - 2017 Michal &#268;iha&#345;", "https://weblate.org")
             + helpLib("Font Awesome",
-                      "Created & Maintained by Dave Gandy", "https://fortawesome.github.io/Font-Awesome/")
+                      "Copyright (c) 2017 Fonticons, Inc.", "https://fontawesome.com")
             + helpLib("LibQxt",
                       "Copyright (c) 2006 - 2011, the LibQxt project", "http://libqxt.org")
             + helpLib("Solarized",
