@@ -43,36 +43,6 @@ class PersistentDisplayItem;
 class QProgressBar;
 class QPushButton;
 
-class UpdatesLocker {
-public:
-    explicit UpdatesLocker(QWidget *widget)
-        : m_widget(widget)
-    {
-    }
-
-    ~UpdatesLocker()
-    {
-        if (m_updatesDisabled)
-            m_widget->setUpdatesEnabled(true);
-    }
-
-    void lock() {
-        if (m_updatesDisabled)
-            return;
-
-        m_updatesDisabled = m_widget->updatesEnabled();
-        if (m_updatesDisabled)
-            m_widget->setUpdatesEnabled(false);
-    }
-
-private:
-    UpdatesLocker(const UpdatesLocker &) = delete;
-    UpdatesLocker &operator =(const UpdatesLocker &) = delete;
-
-    QWidget *m_widget;
-    bool m_updatesDisabled = false;
-};
-
 /** List view of clipboard items. */
 class ClipboardBrowser : public QListView
 {
@@ -358,8 +328,6 @@ class ClipboardBrowser : public QListView
          */
         void updateSizes();
 
-        void updateItemWidgets();
-
         void updateCurrent();
 
         /**
@@ -427,7 +395,6 @@ class ClipboardBrowser : public QListView
         QTimer m_timerSave;
         QTimer m_timerEmitItemCount;
         QTimer m_timerUpdateSizes;
-        QTimer m_timerUpdateItemWidgets;
         QTimer m_timerUpdateCurrent;
         QTimer m_timerDragDropScroll;
         bool m_ignoreMouseMoveWithButtonPressed = false;
@@ -442,8 +409,6 @@ class ClipboardBrowser : public QListView
         QPoint m_dragStartPosition;
 
         int m_filterRow = -1;
-
-        QVector<QPersistentModelIndex> m_itemWidgetsToUpdate;
 };
 
 #endif // CLIPBOARDBROWSER_H
