@@ -81,29 +81,26 @@ CommandWidget::CommandWidget(QWidget *parent)
     connect(ui->checkBoxShowAdvanced, &QCheckBox::stateChanged,
             this, &CommandWidget::onCheckBoxShowAdvancedStateChanged);
 
-    connect(ui->checkBoxAutomatic, &QCheckBox::stateChanged,
-            this, &CommandWidget::onCheckBoxAutomaticStateChanged);
-    connect(ui->checkBoxDisplay, &QCheckBox::stateChanged,
-            this, &CommandWidget::onCheckBoxDisplayStateChanged);
-    connect(ui->checkBoxInMenu, &QCheckBox::stateChanged,
-            this, &CommandWidget::onCheckBoxInMenuStateChanged);
-    connect(ui->checkBoxIsScript, &QCheckBox::stateChanged,
-            this, &CommandWidget::onCheckBoxIsScriptStateChanged);
-    connect(ui->checkBoxGlobalShortcut, &QCheckBox::stateChanged,
-            this, &CommandWidget::onCheckBoxGlobalShortcutStateChanged);
+    for (auto checkBox : findChildren<QCheckBox *>()) {
+        connect(checkBox, &QCheckBox::stateChanged,
+                this, &CommandWidget::updateWidgets);
+    }
+
+    for (auto lineEdit : findChildren<QLineEdit *>()) {
+        connect(lineEdit, &QLineEdit::textEdited,
+                this, &CommandWidget::updateWidgets);
+    }
 
     connect(ui->shortcutButtonGlobalShortcut, &ShortcutButton::shortcutAdded,
-            this, &CommandWidget::onShortcutButtonGlobalShortcutShortcutAdded);
+            this, &CommandWidget::updateWidgets);
     connect(ui->shortcutButtonGlobalShortcut, &ShortcutButton::shortcutRemoved,
-            this, &CommandWidget::onShortcutButtonGlobalShortcutShortcutRemoved);
+            this, &CommandWidget::updateWidgets);
 
     connect(ui->commandEdit, &CommandEdit::changed,
-            this, &CommandWidget::onCommandEditChanged);
+            this, &CommandWidget::updateWidgets);
     connect(ui->commandEdit, &CommandEdit::commandTextChanged,
             this, &CommandWidget::onCommandEditCommandTextChanged);
 
-    ui->widgetAdvanced->hide();
-
     updateWidgets();
 
 #ifdef NO_GLOBAL_SHORTCUTS
@@ -113,8 +110,6 @@ CommandWidget::CommandWidget(QWidget *parent)
     ui->checkBoxGlobalShortcut->setIcon(iconShortcut());
 #endif
 
-    ui->groupBoxCommand->setFocusProxy(ui->commandEdit);
-
     ui->checkBoxAutomatic->setIcon(iconClipboard());
     ui->checkBoxInMenu->setIcon(iconMenu());
     ui->checkBoxIsScript->setIcon(iconScript());
@@ -189,6 +184,9 @@ void CommandWidget::setCommand(const Command &c)
                 ui->shortcutButtonGlobalShortcut);
     ui->comboBoxCopyToTab->setEditText(c.tab);
     ui->comboBoxOutputTab->setEditText(c.outputTab);
+
+    if (c.cmd.isEmpty())
+        ui->tabWidget->setCurrentWidget(ui->tabAdvanced);
 }
 
 void CommandWidget::setFormats(const QStringList &formats)
@@ -197,12 +195,6 @@ void CommandWidget::setFormats(const QStringList &formats)
     setComboBoxItems(ui->comboBoxOutputFormat, formats);
 }
 
-void CommandWidget::resizeEvent(QResizeEvent *event)
-{
-    QWidget::resizeEvent(event);
-    ui->commandEdit->resizeToContent();
-}
-
 void CommandWidget::showEvent(QShowEvent *event)
 {
     AppConfig appConfig;
@@ -227,48 +219,8 @@ void CommandWidget::onCheckBoxShowAdvancedStateChanged(int state)
     const bool showAdvanced = state == Qt::Checked;
     AppConfig appConfig;
     appConfig.setOption(Config::show_advanced_command_settings::name(), showAdvanced);
-    ui->widgetAdvanced->setVisible(showAdvanced);
-    updateWidgets();
-}
-
-void CommandWidget::onCheckBoxAutomaticStateChanged(int)
-{
-    updateWidgets();
-}
-
-void CommandWidget::onCheckBoxDisplayStateChanged(int)
-{
-    updateWidgets();
-}
-
-void CommandWidget::onCheckBoxInMenuStateChanged(int)
-{
-    updateWidgets();
-}
-
-void CommandWidget::onCheckBoxIsScriptStateChanged(int)
-{
-    updateWidgets();
-}
-
-void CommandWidget::onCheckBoxGlobalShortcutStateChanged(int)
-{
-    updateWidgets();
-}
-
-void CommandWidget::onShortcutButtonGlobalShortcutShortcutAdded(const QKeySequence &)
-{
-    updateWidgets();
-}
-
-void CommandWidget::onShortcutButtonGlobalShortcutShortcutRemoved(const QKeySequence &)
-{
-    updateWidgets();
-}
-
-void CommandWidget::onCommandEditChanged()
-{
-    updateWidgets();
+    ui->tabWidget->setVisible(showAdvanced);
+    ui->labelDescription->setVisible(showAdvanced);
 }
 
 void CommandWidget::onCommandEditCommandTextChanged(const QString &command)
@@ -299,9 +251,7 @@ void CommandWidget::updateWidgets()
     ui->groupBoxInMenu->setVisible(inMenu);
     ui->groupBoxCommandOptions->setHidden(!copyOrExecute || ui->commandEdit->isEmpty());
 
-    ui->widgetSpacer->setVisible(ui->widgetAdvanced->isHidden());
-
-    ui->commandEdit->resizeToContent();
+    ui->labelDescription->setText(description());
 
     emitIconChanged();
 }
@@ -310,3 +260,83 @@ void CommandWidget::emitIconChanged()
 {
     emit iconChanged();
 }
+
+QString CommandWidget::description() const
+{
+    const Command cmd = command();
+
+    if (cmd.type() & CommandType::Script)
+        return "<b>Extends scripting</b> or command line.";
+
+    if (cmd.type() & CommandType::Display)
+        return "Changes <b>visual</b> item representation.";
+
+    QString description("<table><tr><td>");
+
+    if (cmd.type() & CommandType::Automatic) {
+        description.append("On <b>clipboard change</b>");
+    } else if (cmd.type() & CommandType::GlobalShortcut) {
+        description.append("On <b>global shortcut</b>");
+    } else if (cmd.type() & CommandType::Menu) {
+        description.append("On <b>menu item or application shortcut</b>");
+    }
+
+    if ( !(cmd.type() & CommandType::GlobalShortcut) ) {
+        if (cmd.input.isEmpty() || cmd.input == mimeText)
+            description.append( QString("<div><b>input format:</b> text</div>") );
+        else if (cmd.input == "!OUTPUT")
+            description.append( QString("<div><b>input format NOT:</b> %1</div>").arg(cmd.output) );
+        else
+            description.append( QString("<div><b>input format:</b> %1</div>").arg(cmd.input) );
+    }
+
+    description.append("</td><td width=15></td><td>");
+
+    const bool isAutomaticOrMenu = cmd.type() & (CommandType::Automatic | CommandType::Menu);
+
+    if ( !cmd.re.isEmpty() && isAutomaticOrMenu ) {
+        description.append(
+            QString("<div>if text matches <b>/%1/</b></div>").arg(cmd.re.pattern()) );
+    }
+
+    if ( !cmd.wndre.isEmpty() && cmd.type() & CommandType::Automatic ) {
+        description.append(
+            QString("<div>if current window title matches <b>/%1/</b></div>").arg(cmd.wndre.pattern()) );
+    }
+
+    if ( !cmd.matchCmd.isEmpty() && isAutomaticOrMenu )
+        description.append("<div>if <b>filter</b> command succeeds</div>");
+
+    description.append("</td><td width=15></td><td>");
+
+    if (cmd.wait) {
+        description.append("<div><b>shows action dialog</b></div>");
+    } else if ( !cmd.cmd.isEmpty() && isAutomaticOrMenu ) {
+        if ( !cmd.output.isEmpty() )
+            description.append( QString("<div><b>output format:</b> %1</div>").arg(cmd.output) );
+        if ( !cmd.outputTab.isEmpty() )
+            description.append( QString("<div><b>output tab:</b> %1</div>").arg(cmd.outputTab) );
+    }
+
+    if ( !cmd.tab.isEmpty() && cmd.type() & CommandType::Automatic )
+        description.append( QString("<div>saves clipboard in tab <b>%1</b></div>").arg(cmd.tab) );
+
+    if (cmd.remove) {
+        if ( cmd.type() & CommandType::Automatic )
+            description.append("<div><b>ignores clipboard</b></div>");
+        else if ( cmd.type() & CommandType::Menu )
+            description.append("<div><b>removes</b> items</div>");
+    } else if (cmd.transform) {
+        if ( cmd.type() & CommandType::Automatic )
+            description.append("<div><b>replaces data</b></div>");
+        else if ( cmd.type() & CommandType::Menu )
+            description.append("<div><b>replaces selected items</b></div>");
+    }
+
+    if (cmd.hideWindow && cmd.type() & CommandType::Menu )
+        description.append("<br/><b>closes</b> main window");
+
+    description.append("</td></tr></table>");
+
+    return description;
+}
