@@ -58,13 +58,11 @@ public:
     void setTabGroupName(const QString &tabGroupName);
 
 signals:
-    /** Signal emitted if tab @a name is accepted. */
-    void accepted(const QString &name, int tabIndex);
+    void newTabNameAccepted(const QString &newName);
+    void barTabNameAccepted(const QString &newName, int tabIndex);
+    void treeTabNameAccepted(const QString &newName, const QString &oldName);
 
-    /** Signal emitted if tab group @a name is accepted. */
-    void accepted(const QString &newName, const QString &oldName);
-
-private slots:
+private:
     void onAccepted();
 
     /**
@@ -74,9 +72,8 @@ private slots:
      */
     void validate();
 
-private:
     Ui::TabDialog *ui;
-    int m_tabIndex;
+    int m_tabIndex = -1;
     QString m_tabGroupName;
     QStringList m_tabs;
 };
