@@ -27,6 +27,7 @@
 #include <QDesktopWidget>
 #include <QListView>
 #include <QSettings>
+#include <QStyleFactory>
 
 #include <cmath>
 
@@ -228,14 +229,29 @@ void Theme::decorateBrowser(QListView *c) const
 
 void Theme::decorateMainWindow(QWidget *mainWindow) const
 {
-    if ( !isMainWindowThemeEnabled() ) {
-        mainWindow->setStyleSheet(QString());
+    QPalette palette = QApplication::palette();
+
+    // This seems to properly reset icon colors.
+    mainWindow->setPalette(palette);
+    mainWindow->setStyleSheet(QString());
+
+    if ( !isMainWindowThemeEnabled() )
         return;
-    }
 
+    const auto bg = color("bg");
+    const auto fg = color("fg");
+    palette.setColor( QPalette::Base, bg );
+    palette.setColor( QPalette::AlternateBase, color("alt_bg") );
+    palette.setColor( QPalette::Text, fg );
+    palette.setColor( QPalette::Window, bg );
+    palette.setColor( QPalette::WindowText, fg );
+    palette.setColor( QPalette::Button, bg );
+    palette.setColor( QPalette::ButtonText, fg );
+    palette.setColor( QPalette::Highlight, color("sel_bg") );
+    palette.setColor( QPalette::HighlightedText, color("sel_fg") );
+
+    mainWindow->setPalette(palette);
     mainWindow->setStyleSheet(
-        "MainWindow{background:" + themeColorString("bg") + "}"
-
         "#searchBar{"
         + themeStyleSheet("search_bar") +
         "}"
@@ -257,7 +273,7 @@ void Theme::decorateMainWindow(QWidget *mainWindow) const
         "#tab_tree, #tab_tree_item{" + themeStyleSheet("tab_tree_css") + "}"
 
         // GTK has incorrect background for branches
-        "#tab_tree::branch:selected{background:" + themeColorString("bg") + "}"
+        "#tab_tree::branch:selected{background:" + serializeColor(bg) + "}"
 
         "#tab_tree::item:selected"
         ",#tab_tree_item[CopyQ_selected=\"true\"]"
@@ -275,8 +291,10 @@ void Theme::decorateMainWindow(QWidget *mainWindow) const
         "}"
 
         // Remove border in toolbars.
-        "QToolBar{border:none}"
-        "QToolBar QToolButton{color:" + themeColorString("fg") + "}"
+        "QToolBar{" + themeStyleSheet("tool_bar_css") + "}"
+        "QToolButton{" + themeStyleSheet("tool_button_css") + "}"
+        "QToolButton:hover{" + themeStyleSheet("tool_button_selected_css") + "}"
+        "QToolButton:pressed{" + themeStyleSheet("tool_button_pressed_css") + "}"
 
         "#menu_bar, #menu_bar::item {"
           + themeStyleSheet("menu_bar_css") + "}"
@@ -285,26 +303,12 @@ void Theme::decorateMainWindow(QWidget *mainWindow) const
         "#menu_bar::item:disabled {"
           + themeStyleSheet("menu_bar_disabled_css") + "}"
 
-        + getMenuStyleSheet("#menu_bar")
-        + getMenuStyleSheet("#centralWidget")
+        + getMenuStyleSheet()
 
         + themeStyleSheet("css")
     );
 }
 
-void Theme::decorateToolBar(QWidget *toolBar) const
-{
-    if ( isMainWindowThemeEnabled() ) {
-        toolBar->setStyleSheet(
-            "QToolBar{" + themeStyleSheet("tool_bar_css") + "}"
-            "QToolButton{" + themeStyleSheet("tool_button_css") + "}"
-            "QToolButton:hover{" + themeStyleSheet("tool_button_selected_css") + "}"
-                    );
-    } else {
-        toolBar->setStyleSheet(QString());
-    }
-}
-
 void Theme::decorateScrollArea(QAbstractScrollArea *scrollArea) const
 {
     const auto scrollbarPolicy = this->scrollbarPolicy();
@@ -420,10 +424,7 @@ void Theme::resetTheme()
 
     m_theme["css"] = Option("");
     m_theme["menu_css"] = Option(
-                "\n    ;border-top: 0.08em solid ${bg + #333}"
-                "\n    ;border-left: 0.08em solid ${bg + #333}"
-                "\n    ;border-bottom: 0.08em solid ${bg - #333}"
-                "\n    ;border-right: 0.08em solid ${bg - #333}"
+                "\n    ;border: 1px solid ${sel_bg}"
                 "\n    ;background: ${bg}"
                 "\n    ;color: ${fg}"
                 );
@@ -499,11 +500,18 @@ void Theme::resetTheme()
                 "\n    ;border: 0"
                 );
     m_theme["tool_button_css"] = Option(
-                "\n    ;background-color: transparent"
+                "\n    ;color: ${fg}"
+                "\n    ;background: ${bg}"
+                "\n    ;border: 0"
+                "\n    ;border-radius: 2px"
                 );
     m_theme["tool_button_selected_css"] = Option(
-                "\n    ;background: ${sel_bg}"
+                "\n    ;background: ${sel_bg - #222}"
                 "\n    ;color: ${sel_fg}"
+                "\n    ;border: 1px solid ${sel_bg}"
+                );
+    m_theme["tool_button_pressed_css"] = Option(
+                "\n    ;background: ${sel_bg}"
                 );
 
     m_theme["search_bar"] = Option(
@@ -590,6 +598,9 @@ void Theme::decorateBrowser(QAbstractScrollArea *c) const
           + unfocusedTheme.themeStyleSheet("sel_item_css") +
         "}"
 
+        // Omit showing current item outline.
+        "#ClipboardBrowser::focus{outline:0}"
+
         "#ClipboardBrowser::item:focus{"
           + themeStyleSheet("cur_item_css") +
         "}"
@@ -640,28 +651,28 @@ QString Theme::themeColorString(const QString &name) const
     return serializeColor( color(name) );
 }
 
-QString Theme::getMenuStyleSheet(const QString &selector) const
+QString Theme::getMenuStyleSheet() const
 {
     const int iconSize = iconFontSizePixels();
     return
         // Remove icon border in menus.
-        selector + " QMenu::item:selected{border:none}"
-        + selector + " QMenu::item{"
+        "#MainWindow QMenu::item:selected{border:none}"
+        "#MainWindow QMenu::item{"
           ";padding:0.2em 1em 0.2em 1em"
           ";padding-left:" + QString::number(iconSize * 2) + "px}"
-        + selector + " QMenu::icon{padding-left:" + QString::number(iconSize / 2) + "px}"
+        + "#MainWindow QMenu::icon{padding-left:" + QString::number(iconSize / 2) + "px}"
 
         // Keep default item highlighted (removing icon border resets the style).
-        + selector + " QMenu::item:default{font-weight:bold}"
+        + "#MainWindow QMenu::item:default{font-weight:bold}"
 
-        + selector + " QMenu {" + themeStyleSheet("menu_css") + "}"
+        + "#MainWindow QMenu {" + themeStyleSheet("menu_css") + "}"
 
-        + selector + " QMenu::item,"
-        + selector + " QMenu::separator {"
+        + "#MainWindow QMenu::item,"
+        + "#MainWindow QMenu::separator {"
           + themeStyleSheet("menu_bar_css") + "}"
-        + selector + " QMenu::item:selected {"
+        + "#MainWindow QMenu::item:selected {"
           + themeStyleSheet("menu_bar_selected_css") + "}"
-        + selector + "  QMenu::item:disabled {"
+        + "#MainWindow  QMenu::item:disabled {"
           + themeStyleSheet("menu_bar_disabled_css") + "}";
 }
 
