@@ -67,9 +67,6 @@ public:
     /** Decorate main window. */
     void decorateMainWindow(QWidget *mainWindow) const;
 
-    /** Decorate tool bar. */
-    void decorateToolBar(QWidget *toolBar) const;
-
     /** Decorate scroll area (toggle scroll bar). */
     void decorateScrollArea(QAbstractScrollArea *scrollArea) const;
 
@@ -118,7 +115,7 @@ private:
     /** Return parsed color name. */
     QString themeColorString(const QString &name) const;
 
-    QString getMenuStyleSheet(const QString &selector) const;
+    QString getMenuStyleSheet() const;
 
     QHash<QString, Option> m_theme;
     Ui::ConfigTabAppearance *ui = nullptr;
