@@ -21,6 +21,7 @@
 
 #include "common/mimetypes.h"
 #include "common/log.h"
+#include "common/processsignals.h"
 #include "common/temporaryfile.h"
 
 #include <QDir>
@@ -118,15 +119,13 @@ bool ItemEditor::start()
     m_lastmodified = m_info.lastModified();
     m_lastSize = m_info.size();
     m_timer->start(500);
-    connect( m_timer, SIGNAL(timeout()),
-             this, SLOT(onTimer()) );
+    connect( m_timer, &QTimer::timeout,
+             this, &ItemEditor::onTimer );
 
     // create editor process
     m_editor = new QProcess(this);
-    connect( m_editor, SIGNAL(finished(int,QProcess::ExitStatus)),
-            this, SLOT(close()) );
-    connect( m_editor, SIGNAL(error(QProcess::ProcessError)),
-            this, SLOT(onError()) );
+    connectProcessFinished(m_editor, this, &ItemEditor::close);
+    connectProcessError(m_editor, this, &ItemEditor::onError);
 
     // use native path for filename to edit
     const auto nativeFilePath = QDir::toNativeSeparators( m_info.absoluteFilePath() );
@@ -137,13 +136,13 @@ bool ItemEditor::start()
     m_editor->closeWriteChannel();
     m_editor->closeReadChannel(QProcess::StandardOutput);
 
-    return true;
+    return m_editor->waitForStarted(10000);
 }
 
 void ItemEditor::close()
 {
     // check if file was modified before closing
-    if ( m_modified || fileModified() )
+    if ( m_modified || wasFileModified() )
         emit fileModified(m_data, m_mime, m_index);
 
     if (m_editor && m_editor->exitCode() != 0 ) {
@@ -162,7 +161,7 @@ void ItemEditor::onError()
     emit closed(this);
 }
 
-bool ItemEditor::fileModified()
+bool ItemEditor::wasFileModified()
 {
     m_info.refresh();
     if ( m_lastmodified != m_info.lastModified() ||  m_lastSize != m_info.size() ) {
@@ -197,13 +196,13 @@ void ItemEditor::onTimer()
 {
     if (m_modified) {
         // Wait until file is fully overwritten.
-        if ( !fileModified() ) {
+        if ( !wasFileModified() ) {
             m_modified = false;
             emit fileModified(m_data, m_mime, m_index);
             m_hash = qHash(m_data);
         }
     } else {
-        m_modified = fileModified();
+        m_modified = wasFileModified();
     }
 }
 
